==> packagevivoaar-1.8.0-4533-20200513.133459-1-sources.jar: com/yy/mobile/vivo/VVYYSDK.kt <==
package com.yy.mobile.vivo

import android.app.Activity
import android.app.Application
import android.app.Dialog
import android.app.ProgressDialog
import android.content.Context
import android.util.Log
import com.unionyy.mobile.vivo.vvpai.impl.ActionRegister
import com.yy.mobile.replugin.ApiBridge
import com.yy.mobile.ui.utils.EnvManager
import com.yy.mobile.unionsdk.FinishListener
import com.yy.mobile.unionsdk.UnionYYSdk
import com.yy.mobile.util.DontProguardClass
import com.yy.mobile.util.DontProguardMethod
import com.yy.mobile.util.log.MLog
import com.yymobile.core.ICoreManagerBase
import com.yymobile.core.broadcastgroup.IRegisteBroadCastCore
import io.reactivex.Observable
import io.reactivex.schedulers.Schedulers
import java.lang.reflect.Proxy

/**
 * Created by wangfeihang on 2019-06-19.
 */
@DontProguardClass
object VVYYSDK : UnionYYSdk() {
    private const val TAG = "VVYYSDK"

    /**
     * 美拍获取我方实现的方法。
     * 调用该方法后，如果yy的sdk还没有被初始化，会先进行sdk的初始化，然后再执行接口内的业务逻辑
     * [actionCls] 双方定义的接口类的class
     * [application] 美拍application，用来进行sdk的初始化
     * [context] 美拍传进来的当前context，用来show sdk加载时的loading弹窗
     */
    fun <Action : Any> obtainAction(
        actionCls: Class<Action>,
        application: Application,
        context: Context
    ): Action? {
        if (isInstalling.get()) {
            Log.e(TAG, "sdk is isInstalling")
            return null
        }

        val invocationHandler = ApiInvocationHandler(
            realObj = { ApiBridge.getApi(actionCls) },
            beforeInvoke = { _, _ ->
                val loadingDialog = showSDKLoadingDialog(context)
                !initYYSdkSuc(application, object : FinishListener {
                    override fun onFinish() {
                        loadingDialog?.dismiss()
                        MLog.info(TAG, "dialog dismiss")
                    }
                })
            }
        )
        return Proxy.newProxyInstance(
            invocationHandler.javaClass.classLoader,
            arrayOf(actionCls),
            invocationHandler
        ) as Action
    }

    private fun showSDKLoadingDialog(context: Context): Dialog? {
        if (context is Activity && !context.isFinishing) {
            val progressDialog = ProgressDialog(context).apply {
                this.setMessage("yysdk正在加载中...")
                this.setCancelable(false)
            }
            progressDialog.show()
            MLog.info(TAG, "dialog showing")
            return progressDialog
        }
        return null
    }


    /**
     * This method will be invoked by inflection. (Magnet/RestartUnionSDK)
     */
    @JvmStatic
    @JvmOverloads
    @DontProguardMethod
    fun initYYSdk(application: Application, finishListener: FinishListener? = null) {
        var listener = finishListener
        if (listener == null) {
            listener = object : FinishListener {
                override fun onFinish() {
                    MLog.info(TAG, "initYYSdk, onFinish")
                }
            }
        }
        initYYSdkSuc(application, listener)
    }

    override fun initYYSdkSuc(application: Application, finishListener: FinishListener): Boolean {
        MLog.info(TAG, "initYYSdk# isInstalling ${isInstalling.get()}")
        MLog.info(TAG, "initYYSdk# isInstalled ${isInstalled.get()}")

        if (isInstalled.get()) {
            finishListener.onFinish()
            return true
        }
        this.addFinishListener(finishListener)
        if (!isInstalling.get() && !isInstalled.get()) {
            MLog.info(TAG, "not isInstalled")
            d?.dispose()
            d = Observable
                .create<Int> {
                    try {
                        this.init(application, true)
                        it.onComplete()
                    } catch (e: Exception) {
                        it.onError(e)
                    }
                }
                .observeOn(Schedulers.newThread())
                .doOnComplete {
                    this.initAsync {
                        EnvManager().startCheck()
                        ICoreManagerBase.getCore(IRegisteBroadCastCore::class.java)
                            ?.registeFeedBackBroadCast()
                    }
                }
                .doOnError {
                    MLog.error(TAG, "initYYSdkSuc error", it)
                    finish(mutableListOf(), false)
                }
                .subscribe()
            ActionRegister.registerForSyn()
            return true
        }
        return false
    }
}

==> packagevivoaar-1.15.0-dev-6098-20200916.072343-1-sources.jar: com/yy/mobile/vivo/VVYYSDK.kt <==
package com.yy.mobile.vivo

import android.app.Activity
import android.app.Application
import android.app.Dialog
import android.app.ProgressDialog
import android.content.Context
import android.util.Log
import com.unionyy.mobile.vivo.vvpai.impl.ActionRegister
import com.yy.mobile.vivo.channel.ChannelCrashSdkWrapper
import com.yy.mobile.replugin.ApiBridge
import com.yy.mobile.unionsdk.FinishListener
import com.yy.mobile.unionsdk.UnionYYSdk
import com.yy.mobile.util.DontProguardClass
import com.yy.mobile.util.DontProguardMethod
import com.yy.mobile.util.log.MLog
import java.lang.reflect.Proxy

/**
 * Created by wangfeihang on 2019-06-19.
 */
@DontProguardClass
object VVYYSDK : UnionYYSdk() {
    private const val TAG = "VVYYSDK"

    /**
     * 美拍获取我方实现的方法。
     * 调用该方法后，如果yy的sdk还没有被初始化，会先进行sdk的初始化，然后再执行接口内的业务逻辑
     * [actionCls] 双方定义的接口类的class
     * [application] 美拍application，用来进行sdk的初始化
     * [context] 美拍传进来的当前context，用来show sdk加载时的loading弹窗
     */
    fun <Action : Any> obtainAction(
        actionCls: Class<Action>,
        application: Application,
        context: Context
    ): Action? {
        if (isInstalling.get()) {
            Log.e(TAG, "sdk is isInstalling")
            return null
        }

        val invocationHandler = ApiInvocationHandler(
            realObj = { ApiBridge.getApi(actionCls) },
            beforeInvoke = { _, _ ->
                val loadingDialog = showSDKLoadingDialog(context)
                !initYYSdkSuc(application, object : FinishListener {
                    override fun onFinish() {
                        loadingDialog?.dismiss()
                        MLog.info(TAG, "dialog dismiss")
                    }
                })
            }
        )
        return Proxy.newProxyInstance(
            invocationHandler.javaClass.classLoader,
            arrayOf(actionCls),
            invocationHandler
        ) as Action
    }

    private fun showSDKLoadingDialog(context: Context): Dialog? {
        if (context is Activity && !context.isFinishing) {
            val progressDialog = ProgressDialog(context).apply {
                this.setMessage("yysdk正在加载中...")
                this.setCancelable(false)
            }
            progressDialog.show()
            MLog.info(TAG, "dialog showing")
            return progressDialog
        }
        return null
    }


    /**
     * This method will be invoked by inflection. (Magnet/RestartUnionSDK)
     */
    @JvmStatic
    @JvmOverloads
    @DontProguardMethod
    fun initYYSdk(application: Application, finishListener: FinishListener? = null) {
        var listener = finishListener
        if (listener == null) {
            listener = object : FinishListener {
                override fun onFinish() {
                    MLog.info(TAG, "initYYSdk, onFinish")
                }
            }
        }
        ChannelCrashSdkWrapper().initCrashSdk(application)
        initYYSdkSuc(application, listener)
    }

    override fun firstSynInitSuccess() {
        ActionRegister.registerForSyn()
    }
}
